Connections — BCI-Framework documentation

# Connections

class `bci_framework.framework.widgets.connection.` `Connection`(core)

  Widget that handle the OpenBCI connection.

  `connect`() → None

    Connect events.

  `connection_fail`(reasons)

    Event for OpenBCI failed connection.

  `connection_ok`() → None

    Event for OpenBCI connected.

  `disconnected_ok`() → None

    OpenBCI disconnected.

  `load_config`() → None

    Load widgets.

  `on_connect`(toggled: bool) → None

    Event to handle connection.

  `on_focus`() → None

    Try to autoconnect.

  `openbci_connect`() → None

    Recollect values from GUI.

  `update_config`(*args, **kwargs) → None

    Save widgets status.

  `update_connections`() → None

    Set widgets for connection modes.

  `update_environ`() → None

    Update environment variables.

class `bci_framework.framework.widgets.connection.` `OpenBCIThread`

  Handle the OpenBCI connection.

  `disconnect`() → None

    Disconnect OpenBCI.

  `run`() → None

    Connect and configure OpenBCI board.

  `session_settings`(*args) → None

    Create a session setting to reuse it after an impedance measurement.

  `stop`() → None

    Kill the trhrad.